# --8<--8<--8<--8<--
#
# Copyright (C) 2015 Smithsonian Astrophysical Observatory
#
# This file is part of CXC::ACIS::ParameterBlock
#
# CXC::ACIS::ParameterBlock is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# -->8-->8-->8-->8--

package CXC::ACIS::ParameterBlock::FEP::TE;

use Moo;
use MooX::StrictConstructor;

extends 'CXC::ACIS::ParameterBlock::FEP';

use CXC::ACIS::ParameterBlock::Types ( qw[ CCDid FEPid Tuple PositiveOrZeroInt ] );

has biasArg => (
    is  => 'ro',
    isa => Tuple[ ( PositiveOrZeroInt ) x 5 ],
);

has biasCompressionSlotIndex => (
    is  => 'ro',
    isa => PositiveOrZeroInt
);


sub _attrs_from_block {

    my $class = shift;

    my ( $block, $fep ) = $_;

    my $attr = $class->next::method( @_,
				     idx_by_fep => [ 'biasCompressionSlotIndex',
						     'biasArg0',
						     'biasArg1',
						     'biasArg2',
						     'biasArg3',
						     'biasArg4',
						   ],

				   );

    ## no critic (ProhibitAccessOfPrivateData)
    $attr->{biasArg} = [ map { delete $attr->{"biasArg$_"} } 0..4 ];

    return $attr;
}

1;

__END__

=head1 NAME

CXC::ACIS::ParameterBlock::FEP::TE - TE mode specific FEP subclass


=head1 SYNOPSIS

    use CXC::ACIS::ParameterBlock::FEP::TE;
    $fep = CXC::ACIS::ParameterBlock::FEP::TE->new( \%attr );



=head1 DESCRIPTION

This class subclasses L<B<CXC::ACIS::ParameterBlock::FEP>> to provide
TE mode specific FEP data.



=head1 INTERFACE

=head2 Methods

=head3 new

Construct a new object.

=head3 Attributes

The following attributes are supported in addition to those in L<B<CXC::ACIS::ParameterBlock::FEP>>:

=head3 biasArg

 I<array of 5 non-negative integers>

=head3 biasCompressionSlotIndex


=head2 Accessor Methods

Each attribute has an eponymously named accessor method


=head1 BUGS AND LIMITATIONS

=for author to fill in:
    A list of known problems with the module, together with some
    indication Whether they are likely to be fixed in an upcoming
    release. Also a list of restrictions on the features the module
    does provide: data types that cannot be handled, performance issues
    and the circumstances in which they may arise, practical
    limitations on the size of data sets, special cases that are not
    (yet) handled, etc.

No bugs have been reported.


=head1 SEE ALSO

L<B<CXC::ACIS::ParameterBlock>>, L<B<CXC::ACIS::ParameterBlock::Utils>>.

=head1 VERSION

Version 0.01

=head1 LICENSE AND COPYRIGHT

Copyright (c) 2015 The Smithsonian Astrophysical Observatory

CXC::ACIS::ParameterBlock is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at
your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

=head1 AUTHOR

Diab Jerius  E<lt>djerius@cfa.harvard.eduE<gt>
