package CXC::ACIS::ParameterBlock::TE;

use CXC::ACIS::ParameterBlock::FEP::TE;

use Moo;

extends 'CXC::ACIS::ParameterBlock::Mode';

has '+block' => (
    handles => [ qw(
          biasCompressionSlotIndex
          dutyCycle
          histogramCount
          ignoreBadPixelMap
          onChip2x2Summing
          primaryExposure
          secondaryExposure
          squeegeeExtraRows
          squeegeeFlushCount
          squeegeeIdle1
          squeegeeIdle2
          squeegeeRows
          subarrayRowCount
          subarrayStartRow
          teBlockSlotIndex
          )
    ],
);


sub fep_from_block {
    shift;
    CXC::ACIS::ParameterBlock::FEP::TE->new_from_block( @_ );
}


1;

__END__

=head1 NAME

CXC::ACIS::ParameterBlock::TE - A TE Mode parameter block

=head1 DESCRIPTION

B<L<CXC::ACIS::ParameterBlock::TE>> represents a TE mode parameter block.

It is a subclass of B<L<CXC::ACIS::ParameterBlock::Mode>>.

=head1 INTERFACE

=head2 Attributes

This class provides the following attributes in addition to those of its
parent classes.

=head3 biasCompressionSlotIndex

=head3 dutyCycle

=head3 histogramCount

=head3 ignoreBadPixelMap

=head3 onChip2x2Summing

=head3 primaryExposure

=head3 secondaryExposure

=head3 squeegeeExtraRows

=head3 squeegeeFlushCount

=head3 squeegeeIdle1

=head3 squeegeeIdle2

=head3 squeegeeRows

=head3 subarrayRowCount

=head3 subarrayStartRow

=head3 teBlockSlotIndex

=head1 BUGS AND LIMITATIONS

No bugs have been reported.


=head1 SEE ALSO

B<L<CXC::ACIS::ParameterBlock>>, B<L<CXC::ACIS::ParameterBlock::Mode>>, B<L<CXC::ACIS::ParameterBlock::FEP>>.

=head1 LICENSE AND COPYRIGHT

Copyright (c) 2015 The Smithsonian Astrophysical Observatory

CXC::ACIS::ParameterBlock is free software: you can redistribute it
and/or modify it under the terms of the GNU General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

=head1 AUTHOR

Diab Jerius  E<lt>djerius@cfa.harvard.eduE<gt>
