# --8<--8<--8<--8<--
#
# Copyright (C) 2015 Smithsonian Astrophysical Observatory
#
# This file is part of CXC::ACIS::ParameterBlock
#
# CXC::ACIS::ParameterBlock is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# -->8-->8-->8-->8--

package CXC::ACIS::ParameterBlock::Window::Base;

use 5.10.0;

use Moo;
use MooX::StrictConstructor;

use Type::Params qw[ validate ];
use CXC::ACIS::ParameterBlock::Types '-all';

has ccdId => (
    is       => 'ro',
    isa      => CCDid,
    required => 1,

);

has ccdColumn => (
    is       => 'ro',
    isa      => CCDcolumn,
    required => 1,

);

has width => (
    is       => 'ro',
    isa      => CCDwidth,
    required => 1,
);

has sampleCycle => (
    is       => 'ro',
    isa      => PositiveOrZeroInt,
    required => 1,
);

has lowerEventAmplitude => (
    is       => 'ro',
    isa      => PositiveOrZeroInt,
    required => 1,
);

has eventAmplitudeRange => (
    is       => 'ro',
    isa      => PositiveInt,
    required => 1,
);



1;

__END__

=head1 NAME

CXC::ACIS::ParameterBlock::Window::Base - A base class for Window specifications

=head1 DESCRIPTION

B<L<CXC::ACIS::ParameterBlock::Window::Base>> is a base class for Window specifications.

=head1 INTERFACE

=head2 methods

This class has the following attributes:

=head3 ccdId

=head3 ccdColumn

=head3 width

=head3 sampleCycle

=head3 lowerEventAmplitude

=head3 eventAmplitudeRange


=head1 BUGS AND LIMITATIONS

No bugs have been reported.


=head1 SEE ALSO

B<L<CXC::ACIS::ParameterBlock>>, B<L<CXC::ACIS::ParameterBlock::Mode>>, B<L<CXC::ACIS::ParameterBlock::FEP>>.

=head1 LICENSE AND COPYRIGHT

Copyright (c) 2015 The Smithsonian Astrophysical Observatory

CXC::ACIS::ParameterBlock is free software: you can redistribute it
and/or modify it under the terms of the GNU General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

=head1 AUTHOR

Diab Jerius  E<lt>djerius@cfa.harvard.eduE<gt>
