# --8<--8<--8<--8<--
#
# Copyright (C) 2015 Smithsonian Astrophysical Observatory
#
# This file is part of CXC::ACIS::ParameterBlock
#
# CXC::ACIS::ParameterBlock is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# -->8-->8-->8-->8--

package CXC::ACIS::ParameterBlock::Window2D;

use 5.10.0;

use Moo;
use MooX::StrictConstructor;

use Type::Params qw[ validate ];
use CXC::ACIS::ParameterBlock::Types '-all';

extends 'CXC::ACIS::ParameterBlock';

has '+block' => (
    is      => 'ro',
    isa     => Object,
    handles => [ qw(
          checksum
          windowSlotIndex
          windowBlockId
          )
    ],

);

has windows => (

    is  => 'ro',
    isa => ArrayRef [ InstanceOf ['CXC::ACIS::ParameterBlock::Window::2D'] ],
    required => 1,

);

has ccd_ids => (
    is       => 'lazy',
    init_arg => undef,
    builder  => sub {
        my $self = shift;
        return [ map { $_->ccdId } @{ $self->windows } ];
    },

);

sub new_from_block {

    my $class = shift;
    my ( $block ) = @_;

    require CXC::ACIS::ParameterBlock::Window::2D;

    my @windows = map  { CXC::ACIS::ParameterBlock::Window::2D->new( $_ ) } @{ $block->windows };

    return $class->new(
        block => $block,
        windows => \@windows,
    );

}

sub window {
    my $self = shift;
    my ( $ccdId ) = validate( \@_, CCDid );

    my ( $window ) = grep { $_->ccdId == $ccdId } @{ $self->windows };

    return $window;
}



1;

__END__

=head1 NAME

CXC::ACIS::ParameterBlock::Window2D - A 2D Window parameter block

=head1 DESCRIPTION

B<L<CXC::ACIS::ParameterBlock::Window2D>> represents a 2D Window parameter block.

It is a subclass of B<L<CXC::ACIS::ParameterBlock>>.

=head1 INTERFACE

=head2 Attributes

This class provides the following attributes in addition to those of its
parent classes.

=head3 windowSlotIndex

=head3 checksum

=head3 windowBlockId

=head3 windows

An arrayref of B<L<CXC::ACIS::ParameterBlock::Window::2D>> objects

=head2 Methods

=head3 ccd_ids

returns a list of the CCD's for which windows are specified.

=head3 window

  $window = $self->window( $ccd_id )

Returns the window for the specified CCD id, C<undef> if none match.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.


=head1 SEE ALSO

B<L<CXC::ACIS::ParameterBlock>>, B<L<CXC::ACIS::ParameterBlock::Mode>>, B<L<CXC::ACIS::ParameterBlock::FEP>>.

=head1 LICENSE AND COPYRIGHT

Copyright (c) 2015 The Smithsonian Astrophysical Observatory

CXC::ACIS::ParameterBlock is free software: you can redistribute it
and/or modify it under the terms of the GNU General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

=head1 AUTHOR

Diab Jerius  E<lt>djerius@cfa.harvard.eduE<gt>
